@@ -1,9 +1,7 @@
 # coding=utf-8
 
 from python_bootstrap.generator.constants import README, LICENSE, GITIGNORE
-from python_bootstrap.utils.SystemUtils import create_folder,\
-    create_file_from_template, create_file_from_string,\
-    make_executable, get_username
+from python_bootstrap.utils.SystemUtils import *
 
 TEMPLATE_SETUP = "python_setup.txt"
 TEMPLATE_CLASS = "python_class.txt"
